@@ -19,11 +19,11 @@ import numpy.linalg as linalg
 from scipy import optimize
 from galpy.potential import dvcircdR, vcirc
 from galpy.actionAngle_src.actionAngleIsochrone import actionAngleIsochrone
-from galpy.potential import IsochronePotential
+from galpy.potential import IsochronePotential, MWPotential
 from galpy.util import bovy_plot, galpyWarning
 _TWOPI= 2.*nu.pi
 _ANGLETOL= 0.02 #tolerance for deciding whether full angle range is covered
-class actionAngleIsochroneApprox():
+class actionAngleIsochroneApprox(object):
     """Action-angle formalism using an isochrone potential as an approximate potential and using a Fox & Binney (2014?) like algorithm to calculate the actions using orbit integrations and a torus-machinery-like angle-fit to get the angles and frequencies (Bovy 2014)"""
     def __init__(self,*args,**kwargs):
         """
@@ -53,17 +53,20 @@ class actionAngleIsochroneApprox():
         HISTORY:
            2013-09-10 - Written - Bovy (IAS)
         """
-        if not kwargs.has_key('pot'): #pragma: no cover
+        if not 'pot' in kwargs: #pragma: no cover
             raise IOError("Must specify pot= for actionAngleIsochroneApprox")
         self._pot= kwargs['pot']
-        if not kwargs.has_key('b') and not kwargs.has_key('ip') \
-                and not kwargs.has_key('aAI'): #pragma: no cover
+        if self._pot == MWPotential:
+            warnings.warn("Use of MWPotential as a Milky-Way-like potential is deprecated; galpy.potential.MWPotential2014, a potential fit to a large variety of dynamical constraints (see Bovy 2015), is the preferred Milky-Way-like potential in galpy",
+                          galpyWarning)
+        if not 'b' in kwargs and not 'ip' in kwargs \
+                and not 'aAI' in kwargs: #pragma: no cover
             raise IOError("Must specify b=, ip=, or aAI= for actionAngleIsochroneApprox")
-        if kwargs.has_key('aAI'):
+        if 'aAI' in kwargs:
             if not isinstance(kwargs['aAI'],actionAngleIsochrone): #pragma: no cover
                 raise IOError("'Provided aAI= does not appear to be an instance of an actionAngleIsochrone")
             self._aAI= kwargs['aAI']
-        elif kwargs.has_key('ip'):
+        elif 'ip' in kwargs:
             ip= kwargs['ip']
             if not isinstance(ip,IsochronePotential): #pragma: no cover
                 raise IOError("'Provided ip= does not appear to be an instance of an IsochronePotential")
@@ -71,23 +74,14 @@ class actionAngleIsochroneApprox():
         else:
             self._aAI= actionAngleIsochrone(ip=IsochronePotential(b=kwargs['b'],
                                                                   normalize=1.))
-        if kwargs.has_key('tintJ'):
-            self._tintJ= kwargs['tintJ']
-        else:
-            self._tintJ= 100.
-        if kwargs.has_key('ntintJ'):
-            self._ntintJ= kwargs['ntintJ']
-        else:
-            self._ntintJ= 10000
+        self._tintJ= kwargs.get('tintJ',100.)
+        self._ntintJ= kwargs.get('ntintJ',10000)
         self._tsJ= nu.linspace(0.,self._tintJ,self._ntintJ)
-        if kwargs.has_key('integrate_method'):
-            self._integrate_method= kwargs['integrate_method']
-        else:
-            self._integrate_method= 'dopr54_c'
+        self._integrate_method= kwargs.get('integrate_method','dopr54_c')
         self._c= False
         ext_loaded= False
-        if ext_loaded and ((kwargs.has_key('c') and kwargs['c'])
-                           or not kwargs.has_key('c')): #pragma: no cover
+        if ext_loaded and (('c' in kwargs and kwargs['c'])
+                           or not 'c' in kwargs): #pragma: no cover
             self._c= True
         else:
             self._c= False
@@ -139,13 +133,13 @@ class actionAngleIsochroneApprox():
                 warnings.warn("Full vertical angle range not covered for at least one object; actions are likely not reliable",galpyWarning)
             danglerI= ((nu.roll(anglerI,-1,axis=1)-anglerI) % _TWOPI)[:,:-1]
             danglezI= ((nu.roll(anglezI,-1,axis=1)-anglezI) % _TWOPI)[:,:-1]
-            if kwargs.has_key('cumul') and kwargs['cumul']:
+            if kwargs.get('cumul',False):
                 sumFunc= nu.cumsum
             else:
                 sumFunc= nu.sum
             jr= sumFunc(jrI*danglerI,axis=1)/sumFunc(danglerI,axis=1)
             jz= sumFunc(jzI*danglezI,axis=1)/sumFunc(danglezI,axis=1)
-            if kwargs.has_key('nonaxi') and kwargs['nonaxi']:
+            if kwargs.get('nonaxi',False):
                 lzI= nu.reshape(acfs[1],R.shape)[:,:-1]
                 anglephiI= nu.reshape(acfs[7],R.shape)
                 danglephiI= ((nu.roll(anglephiI,-1,axis=1)-anglephiI) % _TWOPI)[:,:-1]
@@ -207,36 +201,30 @@ class actionAngleIsochroneApprox():
            2013-09-10 - Written - Bovy (IAS)
         """
         from galpy.orbit import Orbit
-        if kwargs.has_key('nonaxi') and kwargs['nonaxi']:
+        if kwargs.get('nonaxi',False):
             raise NotImplementedError('angles for non-axisymmetric potentials not implemented yet') #once this is implemented, remove the pragma further down
-        if kwargs.has_key('_firstFlip'):
-            _firstFlip= kwargs['_firstFlip']
-        else:
-            _firstFlip= False
+        _firstFlip= kwargs.get('_firstFlip',False)
         #If the orbit was already integrated, set ts to the integration times
         if isinstance(args[0],Orbit) and hasattr(args[0]._orb,'orbit') \
-                and not kwargs.has_key('ts'):
+                and not 'ts' in kwargs:
             kwargs['ts']= args[0]._orb.t
         elif (isinstance(args[0],list) and isinstance(args[0][0],Orbit)) \
                 and hasattr(args[0][0]._orb,'orbit')  \
-                and not kwargs.has_key('ts'):
+                and not 'ts' in kwargs:
             kwargs['ts']= args[0][0]._orb.t
         R,vR,vT,z,vz,phi= self._parse_args(True,_firstFlip,*args)
-        if kwargs.has_key('ts') and not kwargs['ts'] is None:
+        if 'ts' in kwargs and not kwargs['ts'] is None:
             ts= kwargs['ts']
         else:
             ts= nu.empty(R.shape[1])
             ts[self._ntintJ-1:]= self._tsJ
             ts[:self._ntintJ-1]= -self._tsJ[1:][::-1]
-        if kwargs.has_key('maxn'):
-            maxn= kwargs['maxn']
-        else:
-            maxn= 3
+        maxn= kwargs.get('maxn',3)
         if self._c: #pragma: no cover
             pass
         else:
             #Use self._aAI to calculate the actions and angles in the isochrone potential
-            if kwargs.has_key('_acfs'): acfs= kwargs['_acfs']
+            if '_acfs' in kwargs: acfs= kwargs['_acfs']
             else:
                 acfs= self._aAI.actionsFreqsAngles(R.flatten(),
                                                    vR.flatten(),
@@ -258,7 +246,7 @@ class actionAngleIsochroneApprox():
             danglezI= ((nu.roll(anglezI,-1,axis=1)-anglezI) % _TWOPI)[:,:-1]
             jr= nu.sum(jrI*danglerI,axis=1)/nu.sum(danglerI,axis=1)
             jz= nu.sum(jzI*danglezI,axis=1)/nu.sum(danglezI,axis=1)
-            if kwargs.has_key('nonaxi') and kwargs['nonaxi']: #pragma: no cover
+            if kwargs.get('nonaxi',False): #pragma: no cover
                 lzI= nu.reshape(acfs[1],R.shape)[:,:-1]
                 anglephiI= nu.reshape(acfs[7],R.shape)
                 if nu.any((nu.fabs(nu.amax(anglephiI,axis=1)-_TWOPI) > _ANGLETOL)\
@@ -267,7 +255,7 @@ class actionAngleIsochroneApprox():
                 danglephiI= ((nu.roll(anglephiI,-1,axis=1)-anglephiI) % _TWOPI)[:,:-1]
                 lz= nu.sum(lzI*danglephiI,axis=1)/nu.sum(danglephiI,axis=1)
             else:
-                lz= R[:,len(ts)/2]*vT[:,len(ts)/2]
+                lz= R[:,len(ts)//2]*vT[:,len(ts)//2]
             #Now do an 'angle-fit'
             angleRT= dePeriod(nu.reshape(acfs[6],R.shape))
             acfs7= nu.reshape(acfs[7],R.shape)
@@ -319,7 +307,7 @@ class actionAngleIsochroneApprox():
             OmegaZ= nu.sum(atainv[:,1,:]*ATAZ,axis=1)
             Omegaphi[negFreqIndx]= -Omegaphi[negFreqIndx]
             anglephi[negFreqIndx]= _TWOPI-anglephi[negFreqIndx]
-            if kwargs.has_key('_retacfs') and kwargs['_retacfs']:
+            if kwargs.get('_retacfs',False):
                 return (jr,lz,jz,OmegaR,Omegaphi,OmegaZ, #pragma: no cover
                         angleR % _TWOPI,
                         anglephi % _TWOPI,
@@ -358,21 +346,9 @@ class actionAngleIsochroneApprox():
            2013-09-10 - Written - Bovy (IAS)
         """
         #Kwargs
-        if not kwargs.has_key('type'):
-            type= 'araz'
-        else:
-            type= kwargs['type']
-            kwargs.pop('type')
-        if not kwargs.has_key('deperiod'):
-            deperiod= False
-        else:
-            deperiod= kwargs['deperiod']
-            kwargs.pop('deperiod')
-        if not kwargs.has_key('downsample'):
-            downsample= False
-        else:
-            downsample= kwargs['downsample']
-            kwargs.pop('downsample')
+        type= kwargs.pop('type','araz')
+        deperiod= kwargs.pop('deperiod',False)
+        downsample= kwargs.pop('downsample',False)
         #Parse input
         R,vR,vT,z,vz,phi= self._parse_args('a' in type,False,*args)
         #Use self._aAI to calculate the actions and angles in the isochrone potential
@@ -404,9 +380,9 @@ class actionAngleIsochroneApprox():
                 ts= self._tsJ[:-1]
             if type == 'jr':
                 if downsample:
-                    plotx= ts[::int(round(self._ntintJ/400))]
-                    ploty= jr[0,::int(round(self._ntintJ/400))]/jr[0,-1]
-                    plotz= anglerI[0,:-1:int(round(self._ntintJ/400))]
+                    plotx= ts[::int(round(self._ntintJ//400))]
+                    ploty= jr[0,::int(round(self._ntintJ//400))]/jr[0,-1]
+                    plotz= anglerI[0,:-1:int(round(self._ntintJ//400))]
                 else:
                     plotx= ts
                     ploty= jr[0,:]/jr[0,-1]
@@ -425,9 +401,9 @@ class actionAngleIsochroneApprox():
                                     **kwargs)
             elif type == 'lz':
                 if downsample:
-                    plotx= ts[::int(round(self._ntintJ/400))]
-                    ploty= lz[0,::int(round(self._ntintJ/400))]/lz[0,-1]
-                    plotz= anglephiI[0,:-1:int(round(self._ntintJ/400))]
+                    plotx= ts[::int(round(self._ntintJ//400))]
+                    ploty= lz[0,::int(round(self._ntintJ//400))]/lz[0,-1]
+                    plotz= anglephiI[0,:-1:int(round(self._ntintJ//400))]
                 else:
                     plotx= ts
                     ploty= lz[0,:]/lz[0,-1]
@@ -444,9 +420,9 @@ class actionAngleIsochroneApprox():
                                     **kwargs)
             elif type == 'jz':
                 if downsample:
-                    plotx= ts[::int(round(self._ntintJ/400))]
-                    ploty= jz[0,::int(round(self._ntintJ/400))]/jz[0,-1]
-                    plotz= anglezI[0,:-1:int(round(self._ntintJ/400))]
+                    plotx= ts[::int(round(self._ntintJ//400))]
+                    ploty= jz[0,::int(round(self._ntintJ//400))]/jz[0,-1]
+                    plotz= anglezI[0,:-1:int(round(self._ntintJ//400))]
                 else:
                     plotx= ts
                     ploty= jz[0,:]/jz[0,-1]
@@ -462,7 +438,7 @@ class actionAngleIsochroneApprox():
                                     colorbar=True,
                                     **kwargs)
         else:
-            if kwargs.has_key('nonaxi') and kwargs['nonaxi']:
+            if kwargs.get('nonaxi',False):
                 raise NotImplementedError('angles for non-axisymmetric potentials not implemented yet')
             if deperiod:
                 if 'ar' in type:
@@ -495,9 +471,9 @@ class actionAngleIsochroneApprox():
             crange= [vmin,vmax]
             if type == 'araz':
                 if downsample:
-                    plotx= angleRT[0,::int(round(self._ntintJ/400))]
-                    ploty= angleZT[0,::int(round(self._ntintJ/400))]
-                    plotz= anglephiT[0,::int(round(self._ntintJ/400))]
+                    plotx= angleRT[0,::int(round(self._ntintJ//400))]
+                    ploty= angleZT[0,::int(round(self._ntintJ//400))]
+                    plotz= anglephiT[0,::int(round(self._ntintJ//400))]
                 else:
                     plotx= angleRT[0,:]
                     ploty= angleZT[0,:]
@@ -515,9 +491,9 @@ class actionAngleIsochroneApprox():
                                     **kwargs)           
             elif type == 'araphi':
                 if downsample:
-                    plotx= angleRT[0,::int(round(self._ntintJ/400))]
-                    ploty= anglephiT[0,::int(round(self._ntintJ/400))]
-                    plotz= angleZT[0,::int(round(self._ntintJ/400))]
+                    plotx= angleRT[0,::int(round(self._ntintJ//400))]
+                    ploty= anglephiT[0,::int(round(self._ntintJ//400))]
+                    plotz= angleZT[0,::int(round(self._ntintJ//400))]
                 else:
                     plotx= angleRT[0,:]
                     ploty= anglephiT[0,:]
@@ -535,9 +511,9 @@ class actionAngleIsochroneApprox():
                                     **kwargs)           
             elif type == 'azaphi':
                 if downsample:
-                    plotx= angleZT[0,::int(round(self._ntintJ/400))]
-                    ploty= anglephiT[0,::int(round(self._ntintJ/400))]
-                    plotz= angleRT[0,::int(round(self._ntintJ/400))]
+                    plotx= angleZT[0,::int(round(self._ntintJ//400))]
+                    ploty= anglephiT[0,::int(round(self._ntintJ//400))]
+                    plotz= angleRT[0,::int(round(self._ntintJ//400))]
                 else:
                     plotx= angleZT[0,:]
                     ploty= anglephiT[0,:]
