@@ -1,7 +1,5 @@
 from galpy.df_src import diskdf
 from galpy.df_src import surfaceSigmaProfile
-from galpy.df_src import Edf
-from galpy.df_src import isothermdf
 from galpy.df_src import evolveddiskdf
 from galpy.df_src import quasiisothermaldf
 from galpy.df_src import streamdf
@@ -16,7 +14,5 @@ diskdf= diskdf.diskdf
 evolveddiskdf= evolveddiskdf.evolveddiskdf
 expSurfaceSigmaProfile= surfaceSigmaProfile.expSurfaceSigmaProfile
 surfaceSigmaProfile= surfaceSigmaProfile.surfaceSigmaProfile
-Edf= Edf.Edf
-isothermdf= isothermdf.isothermdf
 quasiisothermaldf= quasiisothermaldf.quasiisothermaldf
 streamdf= streamdf.streamdf
