@@ -10,6 +10,7 @@
 #      DFcorrection - class that represents corrections to the input Sigma(R)
 #                     and sigma_R(R) to get closer to the targets
 ###############################################################################
+from __future__ import print_function
 _EPSREL=10.**-14.
 _NSIGMA= 4.
 _INTERPDEGREE= 3
@@ -19,7 +20,7 @@ _PROFILE= False
 import copy
 import re
 import os, os.path
-import cPickle as pickle
+import pickle
 import math
 import numpy as nu
 import scipy as sc
@@ -28,9 +29,10 @@ import scipy.interpolate as interpolate
 from scipy import linalg
 from scipy import stats
 from scipy import optimize
-from surfaceSigmaProfile import *
+from galpy.df_src.surfaceSigmaProfile import *
 from galpy.orbit import Orbit
 from galpy.util.bovy_ars import bovy_ars
+from galpy.util import save_pickles
 from galpy.potential import PowerSphericalPotential
 from galpy.actionAngle import actionAngleAdiabatic, actionAngleAxi
 #scipy version
@@ -41,7 +43,7 @@ except: #pragma: no cover
     raise ImportError( "scipy.__version__ not understood, contact galpy developer, send scipy.__version__")
 _CORRECTIONSDIR=os.path.join(os.path.dirname(os.path.realpath(__file__)),'data')
 _DEGTORAD= math.pi/180.
-class diskdf:
+class diskdf(object):
     """Class that represents a disk DF"""
     def __init__(self,dftype='dehnen',
                  surfaceSigma=expSurfaceSigmaProfile,
@@ -79,7 +81,8 @@ class diskdf:
             self._surfaceSigmaProfile= surfaceSigma(profileParams)
         self._beta= beta
         self._gamma= sc.sqrt(2./(1.+self._beta))
-        if correct or kwargs.has_key('corrections') or kwargs.has_key('rmax') or kwargs.has_key('niter') or kwargs.has_key('npoints'):
+        if correct or 'corrections' in kwargs or 'rmax' in kwargs \
+                or 'niter' in kwargs or 'npoints' in kwargs:
             self._correct= True
             #Load corrections
             self._corr= DFcorrection(dftype=self.__class__,
@@ -138,13 +141,9 @@ class diskdf:
         """
         if isinstance(args[0],Orbit):
             if len(args) == 1:
-                if kwargs.has_key('marginalizeVperp') and \
-                        kwargs['marginalizeVperp']:
-                    kwargs.pop('marginalizeVperp')
+                if kwargs.pop('marginalizeVperp',False):
                     return self._call_marginalizevperp(args[0],**kwargs)
-                elif kwargs.has_key('marginalizeVlos') and \
-                        kwargs['marginalizeVlos']:
-                    kwargs.pop('marginalizeVlos')
+                elif kwargs.pop('marginalizeVlos',False):
                     return self._call_marginalizevlos(args[0],**kwargs)
                 else:
                     return sc.real(self.eval(*vRvTRToEL(args[0]._orb.vxvv[1],
@@ -185,12 +184,12 @@ class diskdf:
         vcirclos= vcirc*math.sin(phi+l)
         #Marginalize
         alphalos= phi+l
-        if not kwargs.has_key('nsigma') or (kwargs.has_key('nsigma') and \
-                                                kwargs['nsigma'] is None):
+        if not 'nsigma' in kwargs or ('nsigma' in kwargs and \
+                                          kwargs['nsigma'] is None):
             nsigma= _NSIGMA
         else:
             nsigma= kwargs['nsigma']
-        if kwargs.has_key('nsigma'): kwargs.pop('nsigma')
+        kwargs.pop('nsigma',None)
         sigmaR2= self.targetSigma2(R)
         sigmaR1= sc.sqrt(sigmaR2)
         #Use the asymmetric drift equation to estimate va
@@ -231,12 +230,12 @@ class diskdf:
         vcircperp= vcirc*math.cos(phi+l)
         #Marginalize
         alphaperp= math.pi/2.+phi+l
-        if not kwargs.has_key('nsigma') or (kwargs.has_key('nsigma') and \
-                                                kwargs['nsigma'] is None):
+        if not 'nsigma' in kwargs or ('nsigma' in kwargs and \
+                                          kwargs['nsigma'] is None):
             nsigma= _NSIGMA
         else:
             nsigma= kwargs['nsigma']
-        if kwargs.has_key('nsigma'): kwargs.pop('nsigma')
+        kwargs.pop('nsigma',None)
         sigmaR2= self.targetSigma2(R)
         sigmaR1= sc.sqrt(sigmaR2)
         #Use the asymmetric drift equation to estimate va
@@ -1654,7 +1653,7 @@ class dehnendf(diskdf):
             out= self._gamma*sc.exp(logsigmaR2-SRE2+self.targetSurfacemass(xE,log=True)-logSigmaR+sc.exp(logOLLE-SRE2)+correction[0])/2./nu.pi
             out_time= (time.time()-start)
             tot_time= one_time+corr_time+targSigma_time+out_time
-            print one_time/tot_time, corr_time/tot_time, targSigma_time/tot_time, out_time/tot_time, tot_time
+            print(one_time/tot_time, corr_time/tot_time, targSigma_time/tot_time, out_time/tot_time, tot_time)
             return out
         else:
             return self._gamma*sc.exp(logsigmaR2-SRE2+self.targetSurfacemass(xE,log=True)-logSigmaR+sc.exp(logOLLE-SRE2)+correction[0])/2./nu.pi
@@ -1769,7 +1768,7 @@ class dehnendf(diskdf):
                                    returnOrbit=returnOrbit,nphi=int(nphi),
                                    los=los,losdeg=losdeg))
         if len(out) > n*nphi:
-            print n, nphi, n*nphi
+            print(n, nphi, n*nphi)
             out= out[0:int(n*nphi)]
         return out
 
@@ -2015,7 +2014,7 @@ def bovy_dblquad(func, a, b, gfun, hfun, args=(), tol=1.48e-08):
     return integrate.romberg(_oned_intFunc,a,b,args=(func,gfun,hfun,tol,args),tol=tol)
 
 
-class DFcorrection:
+class DFcorrection(object):
     """Class that contains the corrections necessary to reach
     exponential profiles"""
     def __init__(self,**kwargs):
@@ -2040,47 +2039,29 @@ class DFcorrection:
         HISTORY:
            2010-03-10 - Written - Bovy (NYU)
         """
-        if not kwargs.has_key('surfaceSigmaProfile'):
+        if not 'surfaceSigmaProfile' in kwargs:
             raise DFcorrectionError("surfaceSigmaProfile not given")
         else:
             self._surfaceSigmaProfile= kwargs['surfaceSigmaProfile']
-        if not kwargs.has_key('rmax'):
-            self._rmax= 5.
-        else:
-            self._rmax= kwargs['rmax']
-        if not kwargs.has_key('niter'):
-            self._niter= 20
-        else:
-            self._niter= kwargs['niter']
-        if not kwargs.has_key('npoints'):
-            if kwargs.has_key('corrections'):
+        self._rmax= kwargs.get('rmax',5.)
+        self._niter= kwargs.get('niter',20)
+        if not 'npoints' in kwargs:
+            if 'corrections' in kwargs:
                 self._npoints= kwargs['corrections'].shape[0]
             else: #pragma: no cover
                 self._npoints= 151 #would take too long to cover
         else:
             self._npoints= kwargs['npoints']
-        if kwargs.has_key('dftype'):
-            self._dftype= kwargs['dftype']
-        else:
-            self._dftype= dehnendf
-        if kwargs.has_key('beta'):
-            self._beta= kwargs['beta']
-        else:
-            self._beta= 0.
+        self._dftype= kwargs.get('dftype',dehnendf)
+        self._beta= kwargs.get('beta',0.)
         self._rs= sc.linspace(_RMIN,self._rmax,self._npoints)
-        if kwargs.has_key('interp_k'):
-            self._interp_k= kwargs['interp_k']
-        else:
-            self._interp_k= _INTERPDEGREE
-        if kwargs.has_key('corrections'):
+        self._interp_k= kwargs.get('interp_k',_INTERPDEGREE)
+        if 'corrections' in kwargs:
             self._corrections= kwargs['corrections']
             if not len(self._corrections) == self._npoints:
                 raise DFcorrectionError("Number of corrections has to be equal to the number of points npoints")
         else:
-            if kwargs.has_key('savedir'):
-                self._savedir= kwargs['savedir']
-            else:
-                self._savedir= _CORRECTIONSDIR
+            self._savedir= kwargs.get('savedir',_CORRECTIONSDIR)
             self._savefilename= self._createSavefilename(self._niter)
             if os.path.exists(self._savefilename):
                 savefile= open(self._savefilename,'rb')
@@ -2228,15 +2209,13 @@ class DFcorrection:
                 thisSurface= currentDF.surfacemass(self._rs[jj])
                 newcorrections[jj,0]= currentDF.targetSurfacemass(self._rs[jj])/thisSurface
                 newcorrections[jj,1]= currentDF.targetSigma2(self._rs[jj])*thisSurface/currentDF.sigma2surfacemass(self._rs[jj])
-                #print jj, newcorrections[jj,:]
+                #print(jj, newcorrections[jj,:])
             corrections*= newcorrections
         #Save
-        savefile= open(self._savefilename,'w')
         picklethis= []
         for arr in list(corrections):
             picklethis.append([float(a) for a in arr])
-        pickle.dump(picklethis,savefile)#We pickle a list for platform-independence
-        savefile.close()
+        save_pickles(self._savefilename,picklethis) #We pickle a list for platform-independence)
         return corrections
     
 class DFcorrectionError(Exception):
