@@ -1,12 +1,15 @@
+import warnings
 import numpy as nu
 import galpy.util.bovy_coords as coords
 from galpy.util.bovy_conversion import physical_conversion
-from FullOrbit import FullOrbit
-from RZOrbit import RZOrbit
-from planarOrbit import planarOrbit, planarROrbit, planarOrbitTop
-from linearOrbit import linearOrbit
+from galpy.util import galpyWarning
+from galpy.orbit_src.FullOrbit import FullOrbit
+from galpy.orbit_src.RZOrbit import RZOrbit
+from galpy.orbit_src.planarOrbit import planarOrbit, planarROrbit, \
+    planarOrbitTop
+from galpy.orbit_src.linearOrbit import linearOrbit
 _K=4.74047
-class Orbit:
+class Orbit(object):
     """General orbit class representing an orbit"""
     def __init__(self,vxvv=None,uvw=False,lb=False,
                  radec=False,vo=None,ro=None,zo=0.025,
@@ -250,7 +253,7 @@ class Orbit:
         """
         self._orb.turn_physical_off()
 
-    def integrate(self,t,pot,method='symplec4_c'):
+    def integrate(self,t,pot,method='symplec4_c',dt=None):
         """
         NAME:
 
@@ -275,6 +278,8 @@ class Orbit:
                    'rk6_c' for a 6-th order Runge-Kutta integrator in C
                    'dopr54_c' for a Dormand-Prince integrator in C (generally the fastest)
 
+           dt= (None) if set, force the integrator to use this basic stepsize; must be an integer divisor of output stepsize (only works for the C integrators that use a fixed stepsize)
+
         OUTPUT:
 
            (none) (get the actual orbit using getOrbit()
@@ -283,8 +288,16 @@ class Orbit:
 
            2010-07-10 - Written - Bovy (NYU)
 
+           2015-06-28 - Added dt keyword - Bovy (IAS)
+
         """
-        self._orb.integrate(t,pot,method=method)
+        from galpy.potential import MWPotential
+        if pot == MWPotential:
+            warnings.warn("Use of MWPotential as a Milky-Way-like potential is deprecated; galpy.potential.MWPotential2014, a potential fit to a large variety of dynamical constraints (see Bovy 2015), is the preferred Milky-Way-like potential in galpy",
+                          galpyWarning)
+        if not _check_integrate_dt(t,dt):
+            raise ValueError('dt input (integrator stepsize) for Orbit.integrate must be an integer divisor of the output stepsize')
+        self._orb.integrate(t,pot,method=method,dt=dt)
 
     def integrate_dxdv(self,dxdv,t,pot,method='dopr54_c',
                        rectIn=False,rectOut=False):
@@ -357,9 +370,8 @@ class Orbit:
         """
         if hasattr(self,'_orbInterp'): delattr(self,'_orbInterp')
         if hasattr(self,'rs'): delattr(self,'rs')
-        sortindx = range(len(self._orb.t))
-        sortindx.sort(lambda x,y: cmp(self._orb.t[x],self._orb.t[y]),
-                      reverse=True)
+        sortindx = list(range(len(self._orb.t)))
+        sortindx.sort(key=lambda x: self._orb.t[x],reverse=True)
         for ii in range(self._orb.orbit.shape[1]):
             self._orb.orbit[:,ii]= self._orb.orbit[sortindx,ii]
         return None
@@ -1457,7 +1469,7 @@ class Orbit:
 
         INPUT:
 
-           t - (optional) time at which to get the time (for consistency reasons)
+           t - (default: integration times) time at which to get the time (for consistency reasons); default is to return the list of times at which the orbit is sampled
 
            ro= (Object-wide default) physical scale for distances to use to convert
 
@@ -3169,15 +3181,13 @@ v           obs=[X,Y,Z,vx,vy,vz] - (optional) position and velocity of observer
                                linOrb._orb.vxvv[3]],
                          **orbSetupKwargs)
 
-    #4 pickling
-    def __getinitargs__(self):
-        if self._orb._roSet:
-            iro= self._orb._ro
-        else:
-            iro= None
-        if self._orb._voSet:
-            ivo= self._orb._vo
-        else:
-            ivo= None
-        return (self._orb.vxvv,False,False,False,ivo,iro,
-                self._orb._zo,self._orb._solarmotion)
+def _check_integrate_dt(t,dt):
+    """Check that the stepszie in t is an integer x dt"""
+    if dt is None:
+        return True
+    mult= round((t[1]-t[0])/dt)
+    if nu.fabs(mult*dt-t[1]+t[0]) < 10.**-10.:
+        return True
+    else:
+        return False
+
