@@ -7,7 +7,7 @@ import galpy.util.bovy_plot as plot
 import galpy.util.bovy_symplecticode as symplecticode
 from galpy.orbit_src.FullOrbit import _integrateFullOrbit
 from galpy.util.bovy_conversion import physical_conversion
-from OrbitTop import OrbitTop
+from galpy.orbit_src.OrbitTop import OrbitTop
 class RZOrbit(OrbitTop):
     """Class that holds and integrates orbits in axisymetric potentials 
     in the (R,z) plane"""
@@ -49,7 +49,7 @@ class RZOrbit(OrbitTop):
                           ro=ro,zo=zo,vo=vo,solarmotion=solarmotion)
         return None
 
-    def integrate(self,t,pot,method='symplec4_c'):
+    def integrate(self,t,pot,method='symplec4_c',dt=None):
         """
         NAME:
            integrate
@@ -64,6 +64,7 @@ class RZOrbit(OrbitTop):
                    'rk4_c' for a 4th-order Runge-Kutta integrator in C
                    'rk6_c' for a 6-th order Runge-Kutta integrator in C
                    'dopr54_c' for a Dormand-Prince integrator in C (generally the fastest)
+           dt= (None) if set, force the integrator to use this basic stepsize; must be an integer divisor of output stepsize
         OUTPUT:
            (none) (get the actual orbit using getOrbit()
         HISTORY:
@@ -73,7 +74,7 @@ class RZOrbit(OrbitTop):
         if hasattr(self,'rs'): delattr(self,'rs')
         self.t= nu.array(t)
         self._pot= pot
-        self.orbit= _integrateRZOrbit(self.vxvv,pot,t,method)
+        self.orbit= _integrateRZOrbit(self.vxvv,pot,t,method,dt)
 
     @physical_conversion('energy')
     def E(self,*args,**kwargs):
@@ -90,16 +91,15 @@ class RZOrbit(OrbitTop):
         HISTORY:
            2010-09-15 - Written - Bovy (NYU)
         """
-        if not kwargs.has_key('pot') or kwargs['pot'] is None:
+        if not 'pot' in kwargs or kwargs['pot'] is None:
             try:
                 pot= self._pot
             except AttributeError:
                 raise AttributeError("Integrate orbit or specify pot=")
-            if kwargs.has_key('pot') and kwargs['pot'] is None:
+            if 'pot' in kwargs and kwargs['pot'] is None:
                 kwargs.pop('pot')          
         else:
-            pot= kwargs['pot']
-            kwargs.pop('pot')
+            pot= kwargs.pop('pot')
         if len(args) > 0:
             t= args[0]
         else:
@@ -136,16 +136,15 @@ class RZOrbit(OrbitTop):
         HISTORY:
            2013-11-30 - Written - Bovy (IAS)
         """
-        if not kwargs.has_key('pot') or kwargs['pot'] is None:
+        if not 'pot' in kwargs or kwargs['pot'] is None:
             try:
                 pot= self._pot
             except AttributeError:
                 raise AttributeError("Integrate orbit or specify pot=")
-            if kwargs.has_key('pot') and kwargs['pot'] is None:
+            if 'pot' in kwargs and kwargs['pot'] is None:
                 kwargs.pop('pot')          
         else:
-            pot= kwargs['pot']
-            kwargs.pop('pot')
+            pot= kwargs.pop('pot')
         if len(args) > 0:
             t= args[0]
         else:
@@ -180,16 +179,15 @@ class RZOrbit(OrbitTop):
         HISTORY:
            2013-11-30 - Written - Bovy (IAS)
         """
-        if not kwargs.has_key('pot') or kwargs['pot'] is None:
+        if not 'pot' in kwargs or kwargs['pot'] is None:
             try:
                 pot= self._pot
             except AttributeError:
                 raise AttributeError("Integrate orbit or specify pot=")
-            if kwargs.has_key('pot') and kwargs['pot'] is None:
+            if 'pot' in kwargs and kwargs['pot'] is None:
                 kwargs.pop('pot')          
         else:
-            pot= kwargs['pot']
-            kwargs.pop('pot')
+            pot= kwargs.pop('pot')
         if len(args) > 0:
             t= args[0]
         else:
@@ -228,9 +226,9 @@ class RZOrbit(OrbitTop):
         HISTORY:
            2011-04-18 - Written - Bovy (NYU)
         """
-        if not kwargs.has_key('OmegaP') or kwargs['OmegaP'] is None:
+        if not 'OmegaP' in kwargs or kwargs['OmegaP'] is None:
             OmegaP= 1.
-            if not kwargs.has_key('pot') or kwargs['pot'] is None:
+            if not 'pot' in kwargs or kwargs['pot'] is None:
                 try:
                     pot= self._pot
                 except AttributeError:
@@ -245,11 +243,9 @@ class RZOrbit(OrbitTop):
             else:
                 if hasattr(pot,'OmegaP'):
                     OmegaP= pot.OmegaP()
-            if kwargs.has_key('OmegaP'):
-                kwargs.pop('OmegaP')         
+            kwargs.pop('OmegaP',None)
         else:
-            OmegaP= kwargs['OmegaP']
-            kwargs.pop('OmegaP')
+            OmegaP= kwargs.pop('OmegaP')
         #Make sure you are not using physical coordinates
         old_physical= kwargs.get('use_physical',None)
         kwargs['use_physical']= False
@@ -369,11 +365,10 @@ class RZOrbit(OrbitTop):
         HISTORY:
            2014-06-16 - Written - Bovy (IAS)
         """
-        if kwargs.get('normed',False):
+        if kwargs.pop('normed',False):
             kwargs['d2']= 'Eznorm'
         else:
             kwargs['d2']= 'Ez'
-        if kwargs.has_key('normed'): kwargs.pop('normed')
         self.plot(*args,**kwargs)
         
     def plotER(self,*args,**kwargs):
@@ -389,11 +384,10 @@ class RZOrbit(OrbitTop):
         HISTORY:
            2014-06-16 - Written - Bovy (IAS)
         """
-        if kwargs.get('normed',False):
+        if kwargs.pop('normed',False):
             kwargs['d2']= 'ERnorm'
         else:
             kwargs['d2']= 'ER'
-        if kwargs.has_key('normed'): kwargs.pop('normed')
         self.plot(*args,**kwargs)
         
     def plotEzJz(self,*args,**kwargs):
@@ -415,19 +409,14 @@ class RZOrbit(OrbitTop):
         labeldict= {'t':r'$t$','R':r'$R$','vR':r'$v_R$','vT':r'$v_T$',
                     'z':r'$z$','vz':r'$v_z$','phi':r'$\phi$',
                     'x':r'$x$','y':r'$y$','vx':r'$v_x$','vy':r'$v_y$'}
-        if not kwargs.has_key('pot'):
+        if not 'pot' in kwargs:
             try:
                 pot= self._pot
             except AttributeError:
                 raise AttributeError("Integrate orbit first or specify pot=")
         else:
-            pot= kwargs['pot']
-            kwargs.pop('pot')
-        if kwargs.has_key('d1'):
-            d1= kwargs['d1']
-            kwargs.pop('d1')
-        else:
-            d1= 't'
+            pot= kwargs.pop('pot')
+        d1= kwargs.pop('d1','t')
         self.EzJz= [(evaluatePotentials(self.orbit[ii,0],self.orbit[ii,3],
                                         pot,t=self.t[ii])-
                      evaluatePotentials(self.orbit[ii,0],0.,pot,t=self.t[ii])+
@@ -435,9 +424,9 @@ class RZOrbit(OrbitTop):
                         nu.sqrt(evaluateDensities(self.orbit[ii,0],0.,pot,
                                                   t=self.t[ii]))\
                         for ii in range(len(self.t))]
-        if not kwargs.has_key('xlabel'):
+        if not 'xlabel' in kwargs:
             kwargs['xlabel']= labeldict[d1]
-        if not kwargs.has_key('ylabel'):
+        if not 'ylabel' in kwargs:
             kwargs['ylabel']= r'$E_z/\sqrt{\rho}$'
         if d1 == 't':
             plot.bovy_plot(nu.array(self.t),nu.array(self.EzJz)/self.EzJz[0],
@@ -458,7 +447,7 @@ class RZOrbit(OrbitTop):
             plot.bovy_plot(self.orbit[:,4],nu.array(self.EzJz)/self.EzJz[0],
                            *args,**kwargs)
 
-def _integrateRZOrbit(vxvv,pot,t,method):
+def _integrateRZOrbit(vxvv,pot,t,method,dt):
     """
     NAME:
        _integrateRZOrbit
@@ -470,6 +459,7 @@ def _integrateRZOrbit(vxvv,pot,t,method):
        pot - Potential instance
        t - list of times at which to output (0 has to be in this!)
        method - 'odeint' or 'leapfrog'
+       dt - if set, force the integrator to use this basic stepsize; must be an integer divisor of output stepsize
     OUTPUT:
        [:,5] array of [R,vR,vT,z,vz] at each t
     HISTORY:
@@ -492,7 +482,7 @@ def _integrateRZOrbit(vxvv,pot,t,method):
         #We hack this by upgrading to a FullOrbit
         this_vxvv= nu.zeros(len(vxvv)+1)
         this_vxvv[0:len(vxvv)]= vxvv
-        tmp_out= _integrateFullOrbit(this_vxvv,pot,t,method)
+        tmp_out= _integrateFullOrbit(this_vxvv,pot,t,method,dt)
         #tmp_out is (nt,6)
         out= tmp_out[:,0:5]
     elif method.lower() == 'odeint':
