@@ -8,7 +8,7 @@ import numpy as nu
 import warnings
 from scipy import special, integrate
 from galpy.util import galpyWarning
-from Potential import Potential
+from galpy.potential_src.Potential import Potential
 _TOL= 1.4899999999999999e-15
 _MAXITER= 20
 class RazorThinExponentialDiskPotential(Potential):
