@@ -2,7 +2,7 @@
 #   SteadyLogSpiralPotential: a steady-state spiral potential
 ###############################################################################
 import math
-from planarPotential import planarPotential
+from galpy.potential_src.planarPotential import planarPotential
 _degtorad= math.pi/180.
 class SteadyLogSpiralPotential(planarPotential):
     """Class that implements a steady-state spiral potential
