@@ -2,7 +2,7 @@
 #   TransientLogSpiralPotential: a transient spiral potential
 ###############################################################################
 import math
-from planarPotential import planarPotential
+from galpy.potential_src.planarPotential import planarPotential
 _degtorad= math.pi/180.
 class TransientLogSpiralPotential(planarPotential):
     """Class that implements a steady-state spiral potential
