@@ -10,7 +10,7 @@ import math as m
 import numpy
 from scipy import special, optimize
 from galpy.util import bovy_conversion
-from Potential import Potential
+from galpy.potential_src.Potential import Potential, kms_to_kpcGyrDecorator
 class TwoPowerSphericalPotential(Potential):
     """Class that implements spherical potentials that are derived from 
     two-power density models
@@ -754,6 +754,7 @@ class NFWPotential(TwoPowerIntegerSphericalPotential):
         self._scale= self.a
         self.hasC= True
         self.hasC_dxdv= True
+        self._nemo_accname= 'NFW'
         return None
 
     def _evaluate(self,R,z,phi=0.,t=0.):
@@ -918,3 +919,33 @@ class NFWPotential(TwoPowerIntegerSphericalPotential):
         x= optimize.brentq(lambda y: (numpy.log(1.+y)-y/(1.+y))/y**3.-1./dc,
                            0.01,100.)
         return x*self.a
+
+    @kms_to_kpcGyrDecorator
+    def _nemo_accpars(self,vo,ro):
+        """
+        NAME:
+
+           _nemo_accpars
+
+        PURPOSE:
+
+           return the accpars potential parameters for use of this potential with NEMO
+
+        INPUT:
+
+           vo - velocity unit in km/s
+
+           ro - length unit in kpc
+
+        OUTPUT:
+
+           accpars string
+
+        HISTORY:
+
+           2014-12-18 - Written - Bovy (IAS)
+
+        """
+        ampl= self._amp*vo**2.*ro
+        vmax= numpy.sqrt(ampl/self.a/ro*0.2162165954) #Take that factor directly from gyrfalcon
+        return "0,%s,%s" % (self.a*ro,vmax)
