@@ -401,6 +401,33 @@ def time_in_Gyr(vo,ro):
     """
     return ro/vo/_kmsInPcMyr
 
+def velocity_in_kpcGyr(vo,ro):
+    """
+    NAME:
+
+       velocity_in_kpcGyr
+
+    PURPOSE:
+
+       convert a velocity to kpc/Gyr
+
+    INPUT:
+
+       vo - velocity unit in km/s
+
+       ro - length unit in kpc
+
+    OUTPUT:
+
+       conversion from units where vo=1. at ro=1.
+
+    HISTORY:
+
+       2014-12-19 - Written - Bovy (IAS)
+
+    """
+    return vo*_kmsInPcMyr
+
 #Decorator to apply these transformations
 def print_physical_warning():
     warnings.warn("The behavior of Orbit member functions has changed in versions > 0.1 to return positions in kpc, velocities in km/s, energies and the Jacobi integral in (km/s)^2, the angular momentum o.L() and actions in km/s kpc, frequencies in 1/Gyr, and times and periods in Gyr if a distance and velocity scale was specified upon Orbit initialization with ro=...,vo=...; you can turn this off by specifying use_physical=False when calling the function (e.g., o=Orbit(...); o.R(use_physical=False)",
@@ -425,25 +452,16 @@ def physical_conversion(quantity,pop=False):
     def wrapper(method):
         @wraps(method)
         def wrapped(*args,**kwargs):
-            if kwargs.has_key('use_physical'):
-                use_physical= kwargs['use_physical']
-            else:
-                use_physical= True
-            if kwargs.has_key('ro'):
-                ro= kwargs['ro']
-            elif hasattr(args[0],'_roSet') and args[0]._roSet:
+            use_physical= kwargs.get('use_physical',True)
+            ro= kwargs.get('ro',None)
+            if ro is None and hasattr(args[0],'_roSet') and args[0]._roSet:
                 ro= args[0]._ro
-            else:
-                ro= None
-            if kwargs.has_key('vo'):
-                vo= kwargs['vo']
-            elif hasattr(args[0],'_voSet') and args[0]._voSet:
+            vo= kwargs.get('vo',None)
+            if vo is None and hasattr(args[0],'_voSet') and args[0]._voSet:
                 vo= args[0]._vo
-            else:
-                vo= None
             #Remove ro and vo kwargs if necessary
-            if pop and kwargs.has_key('ro'): kwargs.pop('ro')
-            if pop and kwargs.has_key('vo'): kwargs.pop('vo')
+            if pop and 'ro' in kwargs: kwargs.pop('ro')
+            if pop and 'vo' in kwargs: kwargs.pop('vo')
             if use_physical and \
                     not (_voNecessary[quantity.lower()] and vo is None) and \
                     not (_roNecessary[quantity.lower()] and ro is None):
