@@ -42,7 +42,7 @@ void bovy_rk4(void (*func)(double, double *, double *,
 			   int, struct potentialArg *),
 	      int,
 	      double *,
-	      int, double *,
+	      int, double, double *,
 	      int, struct potentialArg *,
 	      double, double,
 	      double *,int *);
@@ -57,7 +57,7 @@ void bovy_rk6(void (*func)(double, double *, double *,
 			   int, struct potentialArg *),
 	      int,
 	      double *,
-	      int, double *,
+	      int, double, double *,
 	      int, struct potentialArg *,
 	      double, double,
 	      double *,int *);
@@ -88,7 +88,7 @@ void bovy_dopr54(void (*func)(double, double *, double *,
 			      int, struct potentialArg *),
 		 int,
 		 double *,
-		 int, double *,
+		 int, double, double *,
 		 int, struct potentialArg *,
 		 double, double,
 		 double *,int *);
